==> fxgl-0.2.9-sources.jar: com/almasb/fxgl/scene/menu/MenuEventListener.java <==
/*
 * The MIT License (MIT)
 *
 * FXGL - JavaFX Game Library
 *
 * Copyright (c) 2015-2017 AlmasB (almaslvl@gmail.com)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.almasb.fxgl.scene.menu;

import com.almasb.fxgl.gameplay.SaveLoadManager;
import com.almasb.fxgl.io.SaveFile;
import javafx.beans.property.ReadOnlyStringProperty;

/**
 * Listener for events that occur within menus.
 *
 * @author Almas Baimagambetov (almaslvl@gmail.com)
 */
public interface MenuEventListener {

    void onNewGame();

    void onContinue();

    void onResume();

    void onSave();

    void onLoad(SaveFile saveFile);

    void onDelete(SaveFile saveFile);

    void onLogout();

    void onMultiplayer();

    void onExit();

    void onExitToMainMenu();

    ReadOnlyStringProperty profileNameProperty();

    void restoreDefaultSettings();

    SaveLoadManager getSaveLoadManager();
}

==> fxgl-0.3.1-sources.jar: com/almasb/fxgl/scene/menu/MenuEventListener.java <==
/*
 * The MIT License (MIT)
 *
 * FXGL - JavaFX Game Library
 *
 * Copyright (c) 2015-2017 AlmasB (almaslvl@gmail.com)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.almasb.fxgl.scene.menu;

import com.almasb.fxgl.saving.SaveFile;
import com.almasb.fxgl.saving.SaveLoadManager;
import javafx.beans.property.ReadOnlyStringProperty;

/**
 * Listener for events that occur within menus.
 *
 * @author Almas Baimagambetov (almaslvl@gmail.com)
 */
public interface MenuEventListener {

    void onNewGame();

    void onContinue();

    void onResume();

    void onSave();

    void onLoad(SaveFile saveFile);

    void onDelete(SaveFile saveFile);

    void onLogout();

    void onMultiplayer();

    void onExit();

    void onExitToMainMenu();

    ReadOnlyStringProperty profileNameProperty();

    void restoreDefaultSettings();

    SaveLoadManager getSaveLoadManager();
}
